displayLarge property
TextStyle
get
displayLarge
Largest display style for hero sections and major headlines
Implementation
TextStyle get displayLarge;
Largest display style for hero sections and major headlines
TextStyle get displayLarge;