labelLarge property
TextStyle
get
labelLarge
Large labels for buttons, navigation items, and prominent CTAs
Implementation
TextStyle get labelLarge;
Large labels for buttons, navigation items, and prominent CTAs
TextStyle get labelLarge;