titleLarge property
TextStyle
get
titleLarge
Large titles for card headers, modal titles, and major sections
Implementation
TextStyle get titleLarge;
Large titles for card headers, modal titles, and major sections
TextStyle get titleLarge;