heightSpace method
Creates a SizedBox widget with a dynamic height based on the provided value.
The heightSpace method creates a SizedBox widget with a dynamic height based on the provided value.
value: The value representing a percentage of the initial height value.- Returns: A
SizedBoxwidget with the calculated dynamic height.
Implementation
Widget heightSpace(double value) {
return SizedBox(height: h(value));
}