widthSpace method
Creates a SizedBox widget with a dynamic width based on the provided value.
The widthSpace method creates a SizedBox widget with a dynamic width based on the provided value.
value: The value representing a percentage of the initial width value.- Returns: A
SizedBoxwidget with the calculated dynamic width.
Implementation
Widget widthSpace(double value) {
return SizedBox(width: w(value));
}