Composer class

and allows building adaptive layouts with a single builder function.

Constructors

Composer({required BuildContext context, required bool isLandscape, required bool isPortrait, required bool isMobile, required bool isTablet, required bool isDesktop})
const
Composer.fromBaseContext(BuildContext context)
factory
Composer.fromThis(BuildContext context)
factory

Properties

context BuildContext
final
hashCode int
The hash code for this object.
no setterinherited
isDesktop bool
final
isLandscape bool
final
isMobile bool
final
isPortrait bool
final
isTablet bool
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited