ConsoleLogger class

Constructors

ConsoleLogger()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

debug(String message, {String tag = 'DEBUG'}) → void
General purpose debug log
error(String message, {String tag = 'ERROR'}) → void
Error log
info(String message, {String tag = 'INFO'}) → void
Info log
keyValue(String key, dynamic value, {String keyColor = 'yellow', String valueColor = 'green'}) → void
Key-value pair logging
logDesignUtilsInit({required double designWidth, required double designHeight, required double screenWidth, required double screenHeight, required double scaleWidth, required double scaleHeight, required String mode}) → void
Your original design utils log method
section(String title, {String color = 'cyan'}) → void
Section header for organized logging
separator({String color = 'cyan', int length = 50}) → void
Colorful separator line
setEnabled(bool enabled) → void
Enable or disable all logging
setMinLogLevel(int level) → void
Set minimum log level to display
success(String message, {String tag = 'SUCCESS'}) → void
Success log
warning(String message, {String tag = 'WARNING'}) → void
Warning log