DesignFrame class

Constructors

DesignFrame({required double width, required double height})
const

Properties

hashCode int
The hash code for this object.
no setterinherited
height double
final
isValid bool
You can add custom frames as per your app’s target devices or design specs.
no setter
reversed DesignFrame
Returns a new Frame with width and height swapped
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
width double
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

desktopLarge → const DesignFrame
desktopMedium → const DesignFrame
desktopSmall → const DesignFrame
mobileLarge → const DesignFrame
mobileMedium → const DesignFrame
mobileSmall → const DesignFrame
Common design frame presets representing popular device sizes or breakpoints
tabletLandscape → const DesignFrame
tabletPortrait → const DesignFrame