isValid property
bool
get
isValid
You can add custom frames as per your app’s target devices or design specs.
Implementation
bool get isValid => width > 0 && height > 0;
You can add custom frames as per your app’s target devices or design specs.
bool get isValid => width > 0 && height > 0;