DisplayFlexMedia class

Core responsive flex system for calculating media data.

Constructors

DisplayFlexMedia()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Properties

customBreakpoints List<BreakpointMapper>
List of breakpoints (can be customized).
getter/setter pair
flexColumns int
Total number of columns for your grid system.
getter/setter pair
flexSpacing double
Default spacing between columns.
getter/setter pair

Static Methods

getDisplayDataFromString(String? input) Map<BreakpointMapper, FlexDisplayType>
Parses display type string (e.g., "md-none sm-block") into a map of breakpoints to FlexDisplayType.
getFilledMedia<T>(Map<BreakpointMapper, T>? map, T defaultValue, [bool reversed = false]) Map<BreakpointMapper, T>
Fills any missing breakpoint values in the given map with defaults.
getFlexedDataFromString(String? input) Map<BreakpointMapper, double>
Parses flex data string (e.g., "md-6 sm-12") into a map of breakpoints to column spans.
getTypeFromWidth(double width) BreakpointMapper
Get breakpoint for a given width.