OrkittProgressIndicatorThemeData<T extends OrkittProgressIndicatorThemeData<T>> class abstract

Inheritance

Constructors

OrkittProgressIndicatorThemeData(Color? color, Color? trackColor, double? strokeWidth, double? trackStrokeWidth)

Properties

color Color?
final
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
strokeWidth double?
final
trackColor Color?
final
trackStrokeWidth double?
final
type Object
The extension's type.
no setterinherited

Methods

copyWith() ThemeExtension<T>
Creates a copy of this theme extension with the given fields replaced by the non-null parameter values.
inherited
lerp(covariant ThemeExtension<T>? other, double t) ThemeExtension<T>
Linearly interpolate with another ThemeExtension object.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited