sh property

double get sh

Converts the value to points (pt), where 1 pt = 1/72 inch. double get pt => this * inches / 72; Converts the value to pixels (px). Default unit. Converts the value to a percentage of the available height after SafeArea.

Implementation

/// Converts the value to pixels (px). Default unit.
// double get px => toDouble();

/// Converts the value to a percentage of the available height after `SafeArea`.
double get sh => this * OrkittScreenUtils.safeHeight / 100;