sw property
double
get
sw
Converts the value to a percentage of the available width after SafeArea.
Implementation
double get sw => this * OrkittScreenUtils.safeWidth / 100;
Converts the value to a percentage of the available width after SafeArea.
double get sw => this * OrkittScreenUtils.safeWidth / 100;