isVisible method
Determines if this section item should be visible for a given screen type.
Implementation
bool isVisible(BreakpointMapper type) {
return flex[type] != 0;
}
Determines if this section item should be visible for a given screen type.
bool isVisible(BreakpointMapper type) {
return flex[type] != 0;
}