Seed class

Generate Color Schema Based of Seed Color

Inheritance

Constructors

Seed({required Color seedColor, Brightness brightness = Brightness.light})

Properties

brightness Brightness
final
colorScheme ColorScheme
Generate a ColorScheme from seed color and brightness
no setteroverride
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
seedColor Color
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited