themeData property
ThemeData
get
themeData
Returns the current theme data based on active theme mode
Implementation
ThemeData get themeData => _currentTheme;
Returns the current theme data based on active theme mode
ThemeData get themeData => _currentTheme;