UIContext class

Constructors

UIContext()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Properties

aspectRatio double
Screen aspect ratio (width / height)
no setter
deviceType ScreenType
Device type (mobile, tablet, desktop)
no setter
height double
Full screen height
no setter
isDesktop bool
True if device is desktop
no setter
isLandscape bool
True if device is landscape
no setter
isMobile bool
True if device is mobile
no setter
isPortrait bool
True if device is portrait
no setter
isTablet bool
True if device is tablet
no setter
orientation Orientation
Current orientation
no setter
osType OSType
Operating system type
no setter
pixelRatio double
Current device pixel ratio
no setter
safeHeight double
Safe screen height (excluding system UI)
no setter
safeWidth double
Safe screen width (excluding system UI)
no setter
width double
Full screen width
no setter