UnifiedMarginPadding extension

Provides convenient spacing extensions on num for unified margin, padding, and sized box creation using a fixed unit.

on

Properties

gap SizedBox

Available on num, provided by the UnifiedMarginPadding extension

Gap space: g (width & height)
no setter
gapX SizedBox

Available on num, provided by the UnifiedMarginPadding extension

Horizontal space: width gap
no setter
gapY SizedBox

Available on num, provided by the UnifiedMarginPadding extension

Vertical space: height gap
no setter
m EdgeInsets

Available on num, provided by the UnifiedMarginPadding extension

All sides margin: m
no setter
mb EdgeInsets

Available on num, provided by the UnifiedMarginPadding extension

Margin bottom only: mb
no setter
ml EdgeInsets

Available on num, provided by the UnifiedMarginPadding extension

Margin left only: ml
no setter
mr EdgeInsets

Available on num, provided by the UnifiedMarginPadding extension

Margin right only: mr
no setter
mt EdgeInsets

Available on num, provided by the UnifiedMarginPadding extension

Margin top only: mt
no setter
mx EdgeInsets

Available on num, provided by the UnifiedMarginPadding extension

Margin horizontal (left & right): mx
no setter
my EdgeInsets

Available on num, provided by the UnifiedMarginPadding extension

Margin vertical (top & bottom): my
no setter
p EdgeInsets

Available on num, provided by the UnifiedMarginPadding extension

All sides padding: p
no setter
pb EdgeInsets

Available on num, provided by the UnifiedMarginPadding extension

Padding bottom only: pb
no setter
pl EdgeInsets

Available on num, provided by the UnifiedMarginPadding extension

Padding left only: pl
no setter
pr EdgeInsets

Available on num, provided by the UnifiedMarginPadding extension

Padding right only: pr
no setter
pt EdgeInsets

Available on num, provided by the UnifiedMarginPadding extension

Padding top only: pt
no setter
px EdgeInsets

Available on num, provided by the UnifiedMarginPadding extension

Padding horizontal (left & right): px
no setter
py EdgeInsets

Available on num, provided by the UnifiedMarginPadding extension

Padding vertical (top & bottom): py
no setter
s SizedBox

Available on num, provided by the UnifiedMarginPadding extension

Square space: s (width & height)
no setter