AppOrientation enum

Enum representing different orientation lock modes

Inheritance
Available extensions

Values

portraitUp → const AppOrientation
portraitDown → const AppOrientation
landscapeLeft → const AppOrientation
landscapeRight → const AppOrientation
portraitOnly → const AppOrientation
landscapeOnly → const AppOrientation
none → const AppOrientation

Properties

hashCode int
The hash code for this object.
no setterinherited
index int
A numeric identifier for the enumerated value.
no setterinherited
name String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
orientations List<DeviceOrientation>

Available on AppOrientation, provided by the AppOrientationLockExtension extension

no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

values → const List<AppOrientation>
A constant List of the values in this enum, in order of their declaration.