controller property
Controls the text being edited.
If null, an internal controller is created using initialValue.
Implementation
final TextEditingController? controller;
Controls the text being edited.
If null, an internal controller is created using initialValue.
final TextEditingController? controller;