cursorOpacityAnimates property
Whether the cursor will animate from fully transparent to fully opaque.
Implementation
final bool? cursorOpacityAnimates;
Whether the cursor will animate from fully transparent to fully opaque.
final bool? cursorOpacityAnimates;