enableInteractiveSelection property
Whether to enable user interface affordances for changing the text selection.
Implementation
final bool enableInteractiveSelection;
Whether to enable user interface affordances for changing the text selection.
final bool enableInteractiveSelection;