enabled property
Whether the text field is interactive.
If false, the text field is grayed out and disabled.
Implementation
final bool enabled;
Whether the text field is interactive.
If false, the text field is grayed out and disabled.
final bool enabled;