expands property
Whether the text field expands to fill available vertical space.
If true, the text field will expand to fill its parent.
Implementation
final bool expands;
Whether the text field expands to fill available vertical space.
If true, the text field will expand to fill its parent.
final bool expands;