keyboardType property
The type of keyboard to display for text input.
Defaults to TextInputType.text for single-line inputs and TextInputType.multiline for multi-line inputs.
Implementation
final TextInputType keyboardType;
The type of keyboard to display for text input.
Defaults to TextInputType.text for single-line inputs and TextInputType.multiline for multi-line inputs.
final TextInputType keyboardType;