maxLength property
The maximum number of characters (Unicode scalar values) to allow.
If set, a character counter will be displayed below the field.
Implementation
final int? maxLength;
The maximum number of characters (Unicode scalar values) to allow.
If set, a character counter will be displayed below the field.
final int? maxLength;