maxLines property
The maximum number of lines for the text to span.
Defaults to 1. Null means unlimited number of lines.
Implementation
final int? maxLines;
The maximum number of lines for the text to span.
Defaults to 1. Null means unlimited number of lines.
final int? maxLines;