minLines property
The minimum number of lines to occupy.
Must be null or greater than zero. If specified, the text input will expand to at least this many lines.
Implementation
final int? minLines;
The minimum number of lines to occupy.
Must be null or greater than zero. If specified, the text input will expand to at least this many lines.
final int? minLines;