onLineCountChange property
Called when the line count changes.
Note: This callback won't be called if the input doesn't get a higher height, such as when the maxLines limit has been reached.
Implementation
final ValueChanged<int>? onLineCountChange;
Called when the line count changes.
Note: This callback won't be called if the input doesn't get a higher height, such as when the maxLines limit has been reached.
final ValueChanged<int>? onLineCountChange;