readOnly property
Whether the text field should be read-only.
Read-only text fields cannot be modified, but may still be selectable.
Implementation
final bool readOnly;
Whether the text field should be read-only.
Read-only text fields cannot be modified, but may still be selectable.
final bool readOnly;