textDirection property
The directionality of the text.
If null, the directionality is inherited from the context.
Implementation
final TextDirection? textDirection;
The directionality of the text.
If null, the directionality is inherited from the context.
final TextDirection? textDirection;