OtpDecoration class

Constructors

OtpDecoration({Color borderColor = Colors.white12, Color focusBorderColor = const Color(0xFF1976D2), Color successBorderColor = const Color(0xFF2E7D32), Color errorBorderColor = const Color(0xFFD32F2F), double borderWidth = 1.5, double focusBorderWidth = 2.0, double borderRadius = 12.0, Color? boxColor, Color focusedBoxColor = Colors.white, List<BoxShadow>? boxShadow, List<BoxShadow>? focusedBoxShadow})
const

Properties

borderColor Color
final
borderRadius double
final
borderWidth double
final
boxColor Color?
final
boxShadow List<BoxShadow>?
final
errorBorderColor Color
final
focusBorderColor Color
final
focusBorderWidth double
final
focusedBoxColor Color
final
focusedBoxShadow List<BoxShadow>?
final
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
successBorderColor Color
final

Methods

copyWith({Color? borderColor, Color? focusBorderColor, Color? successBorderColor, Color? errorBorderColor, double? borderWidth, double? focusBorderWidth, double? borderRadius, Color? boxColor, Color? focusedBoxColor, List<BoxShadow>? boxShadow, List<BoxShadow>? focusedBoxShadow}) OtpDecoration
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited