ResponsiveColumn extension
Extension for Column widget to provide responsive padding and spacing
- on
Methods
-
alignChildrenHorizontally(
{CrossAxisAlignment alignment = CrossAxisAlignment.start}) → Column -
Available on Column, provided by the ResponsiveColumn extension
Aligns children horizontally (start, center, or end) -
alignChildrenVertically(
{MainAxisAlignment alignment = MainAxisAlignment.start}) → Column -
Available on Column, provided by the ResponsiveColumn extension
Aligns children vertically (start, center, or end) -
centerChildren(
) → Column -
Available on Column, provided by the ResponsiveColumn extension
Centers all children within the Column -
renderConditionally(
bool condition) → Column -
Available on Column, provided by the ResponsiveColumn extension
Conditionally render children based on a condition -
withResponsivePadding(
{required BuildContext context, double smallPadding = 8.0, double mediumPadding = 16.0, double largePadding = 24.0}) → Column -
Available on Column, provided by the ResponsiveColumn extension
Adds responsive padding to the Column based on screen size -
withResponsiveSpacing(
{required BuildContext context, double smallSpacing = 8.0, double mediumSpacing = 16.0, double largeSpacing = 24.0}) → Column -
Available on Column, provided by the ResponsiveColumn extension
Adds responsive spacing between children