ResponsiveRow extension

Extension for Row widget to provide responsive padding and spacing

on

Methods

alignChildrenHorizontally({MainAxisAlignment alignment = MainAxisAlignment.start}) Row

Available on Row, provided by the ResponsiveRow extension

Aligns children horizontally (start, center, or end)
alignChildrenVertically({CrossAxisAlignment alignment = CrossAxisAlignment.start}) Row

Available on Row, provided by the ResponsiveRow extension

Aligns children vertically (start, center, or end)
centerChildren() Row

Available on Row, provided by the ResponsiveRow extension

Centers all children within the Row
renderConditionally(bool condition) Row

Available on Row, provided by the ResponsiveRow extension

Conditionally render children based on a condition
withResponsivePadding({required BuildContext context, double smallPadding = 8.0, double mediumPadding = 16.0, double largePadding = 24.0}) Row

Available on Row, provided by the ResponsiveRow extension

Adds responsive padding to the Row based on screen size
withResponsiveSpacing({required BuildContext context, double smallSpacing = 8.0, double mediumSpacing = 16.0, double largeSpacing = 24.0}) Row

Available on Row, provided by the ResponsiveRow extension

Adds responsive spacing between children