UiTextFieldBorder class

Configuration class for customizing text field borders

Constructors

UiTextFieldBorder({InputBorder? enabledBorder, InputBorder? focusedBorder, InputBorder? errorBorder, InputBorder? focusedErrorBorder, InputBorder? disabledBorder})
const

Properties

disabledBorder InputBorder?
final
enabledBorder InputBorder?
final
errorBorder InputBorder?
final
focusedBorder InputBorder?
final
focusedErrorBorder InputBorder?
final
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited