WidgetStackExtensions extension

on

Methods

aligned([AlignmentGeometry alignment = Alignment.center]) Widget

Available on Widget, provided by the WidgetStackExtensions extension

Wraps the widget in an Align widget
centered() Widget

Available on Widget, provided by the WidgetStackExtensions extension

Wraps the widget in a Center widget
positioned({double? top, double? left, double? right, double? bottom, double? width, double? height}) Widget

Available on Widget, provided by the WidgetStackExtensions extension

Places the widget inside a Stack using Positioned If any values are null, it behaves as partially positioned.
positionedFill() Widget

Available on Widget, provided by the WidgetStackExtensions extension

Wraps the widget in a Positioned.fill
positionedFromRect(Rect rect) Widget

Available on Widget, provided by the WidgetStackExtensions extension

Wraps in a Positioned.fromRect (helper for Rect positioning)
stackedWith(List<Widget> children, {AlignmentGeometry alignment = Alignment.topLeft, StackFit fit = StackFit.loose, Clip clipBehavior = Clip.hardEdge}) Widget

Available on Widget, provided by the WidgetStackExtensions extension

Wraps the widget in a Stack with other children