utils library
Classes
-
AppData<
T> -
AppFailure<
T> -
AppLoading<
T> -
AppState<
T> - ColorMap
- Represents a color palette generated from quantization.
- ColorVolumeBox
- Represents a color volume box for quantization.
- ComposerCycleManager
- CustomScrollBehavior
- Custom Scroll Behavior
- DataImageProvider
- Debug
- Global Debug utility
- Fake
- FakeConversation
- FakeData
- FakePerson
- FakeProduct
- FakeUsers
- FutureUtils
- Future Helpers
- KeyboardVisibilityBuilder
- A widget that rebuilds when the keyboard visibility changes.
- KeyboardVisibilityController
- A lightweight widget and controller to detect keyboard visibility using MediaQuery. No platform channel or external dependency required. Controller for tracking keyboard visibility using ChangeNotifier.
- Patterns
- Predefined Patterns for different validation
-
PriorityQueue<
T> - A generic priority queue implementation.
- SystemUI
- System UI Utilities
- TimeFormatter
- Validator
-
A utility class that provides common form field validators.
All validators return
nullif the input is valid, otherwise return a string error message. - Zero
Enums
- LogLevel
- Log levels
- TimeOfDayGreeting
Extensions
- AbsoluteValue on num
-
AddIfAbsent
on Map<
K, V> -
AngleBetweenVectors
on List<
num> -
AsyncUtilities
on Future<
T> - Async Utilities Functions
-
AverageList
on List<
num> - BoolExtensions on bool
-
Extension for boolean (
bool) values to provide utility methods for common operations like toggling, conditionally executing actions, and converting to different string representations. -
ChunkList
on List<
T> - ClampValue on num
- ColorExtensions on Color
-
Extension on
Colorto provide additional utility methods for color manipulation and analysis. - ColorTextStyleExtension on Color
- Extension on Color to create text styles with specific colors.
- ComposerLifecycle on BuildContext
-
ContainsAny
on List<
T> - CountChar on String
- CurrencyExtension on num
- DateExtension on DateTime
-
Extension for
DateTimeproviding utility methods for common date-time operations. - DegreesToRadians on num
-
DistinctBy
on Iterable<
T> - DurationUtils on Duration
- EmojiExtension on String
-
EuclideanDistance
on Point<
num> - Exponential on num
- ExtendJson on Map
- Factorial on int
-
FindIndex
on List<
T> -
FindOrDefault
on List<
T> - Focus on BuildContext
- IntExtensions on int?
- IntToDuration on int
-
IsSorted
on List<
T> -
JoinList
on List<
T> -
LastElement
on List<
T> - ListGenerator on int
-
MapStringToInt
on Map<
String, String> -
MapToList
on Map<
T, V> -
MaxMinIndex
on List<
T> -
Mean
on List<
num> -
Median
on List<
num> -
MergeList
on List<
T> -
MultiFilterList
on List<
T> - NetworkExtensions on String
- Network Utilities Extensions for Dart & Flutter
- NetworkStatus on InternetAddress
- Power on num
- RadiansToDegrees on num
- RandomRange on int
- RangeList on int
-
RemoveDuplicates
on List<
T> -
RemoveFirstOccurrence
on List<
T> -
RemoveNulls
on List<
T?> -
RepeatList
on List<
T> -
ResultFutureExtension
on Future<
Result< T, AppError> > -
ResultUtils
on Future<
T> -
ReverseList
on List<
T> - RoundToDecimal on num
- ScrollControllerExtensions on ScrollController
- Extension for ScrollController providing additional scroll functionality.
-
ShuffleList
on List<
T> - SignOfNumber on num
-
SortBy
on List<
T> - SplitFixedLength on String
- SquareRoot on num
-
StreamExtensions
on Stream<
T> - Batch Processing & Mapping for Streams
- StringExt on String
- String Extensions
- StringExtension on String
- String Extension to add useful utility methods
-
StringListToMap
on List<
String> - TextStyleBuilder on num
- A comprehensive text style extension for Flutter that provides a fluent interface for building and customizing text styles.
- TextStyleEnhancements on TextStyle
- Extension on TextStyle for additional modifications and utilities.
-
ToListOfMaps
on Iterable<
T>
Properties
- alphaRegExp → RegExp
-
Regular Expression for Alphabet characters
final
-
flutterWidgets
→ HashSet<
String> -
final
Functions
-
debug(
String? message, {String? tag}) → void -
extend(
Map target, Map source, [Iterable< Map> ? sources]) → Map -
extendAll(
Map target, Iterable< Map> sources) → Map -
getPaletteFromBytes(
Uint8List imageData, int width, int height, [int? colorCount, int? quality]) → Future< List< List< ?>int> > - Extracts a color palette from raw image bytes.
-
getPaletteFromImage(
Uint8List imageData, int colorCount, int quality) → Future< List< Color> > -
Extracts a color palette from an
Imageobject. -
quantize(
List< List< pixels, int maxColors) → ColorMap?int> > - Quantizes an image's colors using the Median Cut Algorithm.
Typedefs
- KeyboardVisibilityWidgetBuilder = Widget Function(BuildContext context, bool isKeyboardVisible)
-
Signature for the builder function which returns
isKeyboardVisible.