AppLoading<T> class

Inheritance

Constructors

AppLoading()
const

Properties

hasData bool
no setterinherited
hasError bool
no setterinherited
hashCode int
The hash code for this object.
no setterinherited
isLoading bool
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

map<U>(U transform(T value)) AppState<U>
Transform data value, keep state type
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited
when<R>({required R loading(), required R data(T data), required R failure(AppError error)}) → R
Pattern matching
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited