ColorVolumeBox class

Represents a color volume box for quantization.

Constructors

ColorVolumeBox(List<List<int>> pixels)
ColorVolumeBox.fromPixels(List<List<int>> pixels)
factory

Properties

averageColor List<int>
no setter
hashCode int
The hash code for this object.
no setterinherited
pixelCount int
no setter
pixels List<List<int>>
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
split() → (ColorVolumeBox, ColorVolumeBox?)
Splits the color volume box into two smaller boxes.
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited