tomorrow property
DateTime
get
tomorrow
Tomorrow at the same hour, minute, and second as now.
Implementation
static DateTime get tomorrow => DateTime.now().nextDay;
Tomorrow at the same hour, minute, and second as now.
static DateTime get tomorrow => DateTime.now().nextDay;