yesterday property
DateTime
get
yesterday
Yesterday at the same hour, minute, and second as now.
Implementation
static DateTime get yesterday => DateTime.now().previousDay;
Yesterday at the same hour, minute, and second as now.
static DateTime get yesterday => DateTime.now().previousDay;