Debug class

Global Debug utility

Constructors

Debug()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Properties

showTimestamp bool
If true, includes timestamp in log
getter/setter pair
simple bool
If true, prints only raw messages (no emoji, no colors, no formatting)
getter/setter pair

Static Methods

bug(Object? message, {String? tag}) → void
Log shortcuts
custom(Object? message, {required String emoji, required int ansiColorCode, String? tag}) → void
error(Object? message, {String? tag}) → void
info(Object? message, {String? tag}) → void
log(Object? message, {LogLevel level = LogLevel.info, String? tag, String? emoji, int? ansiColorCode}) → void
Logs a message with styling
success(Object? message, {String? tag}) → void
warning(Object? message, {String? tag}) → void