Fake class

Constructors

Fake()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Properties

productImages List<String>
getter/setter pair

Constants

avatars → const List<String>
categories → const List<String>
commentsList → const List<List<String>>
emails → const List<String>
messages → const List<String>
names → const List<String>
passwords → const List<String>
productDescriptions → const List<String>
productNames → const List<String>
usernames → const List<String>