FakeConversation class

Constructors

FakeConversation({required String id, required String senderName, required String senderAvatarUrl, required String lastMessage, required DateTime timestamp, bool isRead = false, bool isTyping = false})

Properties

hashCode int
The hash code for this object.
no setterinherited
id String
final
isRead bool
final
isTyping bool
final
lastMessage String
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
senderAvatarUrl String
final
senderName String
final
timestamp DateTime
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited