FakeData class
Constructors
- FakeData()
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
generateConversations(
int count) → List< FakeConversation> -
generatePersons(
int count) → List< FakePerson> -
generateProducts(
int count) → List< FakeProduct> -
generateUsers(
int count) → List< FakeUsers>