FakeProduct class

Constructors

FakeProduct({required String id, required String name, required String description, required double price, required String imageUrl, required String category, required List<String> comments})

Properties

category String
final
comments List<String>
final
description String
final
hashCode int
The hash code for this object.
no setterinherited
id String
final
imageUrl String
final
name String
final
price double
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited