FutureUtils class

Future Helpers

Constructors

FutureUtils()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

waitAll<T>(List<Future<T>> futures, {bool ignoreErrors = false}) Future<List<T>>
Waits for multiple Futures safely