ListGenerator extension
- on
Methods
-
generateList<
T> ({required T itemBuilder(int)}) → List< T> -
Available on int, provided by the ListGenerator extension
Generates a List of values based on the number.
Available on int, provided by the ListGenerator extension
Generates a List of values based on the number.