ScrollControllerExtensions extension

Extension for ScrollController providing additional scroll functionality.

on

Properties

isAtBottom bool

Available on ScrollController, provided by the ScrollControllerExtensions extension

Checks if the current scroll position is at the bottom of the scroll view.
no setter
isAtTop bool

Available on ScrollController, provided by the ScrollControllerExtensions extension

Checks if the current scroll position is at the top of the scroll view.
no setter

Methods

animateToPosition(double offset, {Duration duration = const Duration(milliseconds: 300), Curve curve = Curves.easeInOut}) Future<void>

Available on ScrollController, provided by the ScrollControllerExtensions extension

Scrolls the ScrollController to the given position with smooth animation.
isItemVisible(int index, double itemHeight) bool

Available on ScrollController, provided by the ScrollControllerExtensions extension

Checks if the item at the given index is currently visible within the scroll view.
scrollByOffset(double offset, {Duration duration = const Duration(milliseconds: 300), Curve curve = Curves.easeInOut}) Future<void>

Available on ScrollController, provided by the ScrollControllerExtensions extension

Scrolls the ScrollController by the given offset (smooth scroll).
scrollToBottom({Duration duration = const Duration(milliseconds: 300), Curve curve = Curves.easeInOut}) Future<void>

Available on ScrollController, provided by the ScrollControllerExtensions extension

Scrolls the ScrollController to the bottom (maximum scroll extent) with smooth animation.
scrollToIndex(int index, double itemHeight, {Duration duration = const Duration(milliseconds: 300), Curve curve = Curves.easeInOut}) Future<void>

Available on ScrollController, provided by the ScrollControllerExtensions extension

Scrolls the ScrollController to the given index with smooth animation.
scrollToIndexIfNotVisible(int index, double itemHeight, {Duration duration = const Duration(milliseconds: 300), Curve curve = Curves.easeInOut}) Future<void>

Available on ScrollController, provided by the ScrollControllerExtensions extension

Scrolls to the given index only if the item is not visible already.
scrollToPositionIfNotAtBottom(double offset, {Duration duration = const Duration(milliseconds: 300), Curve curve = Curves.easeInOut}) Future<void>

Available on ScrollController, provided by the ScrollControllerExtensions extension

Scrolls to the given position only if the position is not at the bottom already.
scrollToPositionIfNotAtTop(double offset, {Duration duration = const Duration(milliseconds: 300), Curve curve = Curves.easeInOut}) Future<void>

Available on ScrollController, provided by the ScrollControllerExtensions extension

Scrolls to the given position only if the position is not at the top already.
scrollToTop({Duration duration = const Duration(milliseconds: 300), Curve curve = Curves.easeInOut}) Future<void>

Available on ScrollController, provided by the ScrollControllerExtensions extension

Scrolls the ScrollController to the top (offset 0) with smooth animation.