isAtTop property
bool
get
isAtTop
Checks if the current scroll position is at the top of the scroll view.
Implementation
bool get isAtTop {
return position.pixels <= position.minScrollExtent;
}
Checks if the current scroll position is at the top of the scroll view.
bool get isAtTop {
return position.pixels <= position.minScrollExtent;
}