isNumeric method
Returns true if the string contains only numeric characters.
Implementation
bool isNumeric() => RegExp(r'^\d+$').hasMatch(this);
Returns true if the string contains only numeric characters.
bool isNumeric() => RegExp(r'^\d+$').hasMatch(this);