isDoc property
bool
get
isDoc
Checks if the string is a valid document URL.
Implementation
bool get isDoc => hasMatch(Patterns.doc);
Checks if the string is a valid document URL.
bool get isDoc => hasMatch(Patterns.doc);