isEmptyOrNull property
bool
get
isEmptyOrNull
Returns true if the string is either null or empty.
Implementation
bool get isEmptyOrNull => isEmpty || this == 'null';
Returns true if the string is either null or empty.
bool get isEmptyOrNull => isEmpty || this == 'null';