isExcel property
bool
get
isExcel
Checks if the string is a valid Excel file URL.
Implementation
bool get isExcel => hasMatch(Patterns.excel);
Checks if the string is a valid Excel file URL.
bool get isExcel => hasMatch(Patterns.excel);