isImage property
bool
get
isImage
Checks if the string is a valid image URL.
Implementation
bool get isImage => hasMatch(Patterns.image);
Checks if the string is a valid image URL.
bool get isImage => hasMatch(Patterns.image);