isTxt property
bool
get
isTxt
Checks if the string is a valid text file URL.
Implementation
bool get isTxt => hasMatch(Patterns.txt);
Checks if the string is a valid text file URL.
bool get isTxt => hasMatch(Patterns.txt);