isVideo property
bool
get
isVideo
Checks if the string is a valid video URL.
Implementation
bool get isVideo => hasMatch(Patterns.video);
Checks if the string is a valid video URL.
bool get isVideo => hasMatch(Patterns.video);