toBool method
Converts the string to a boolean value based on 'true' or 'false' string.
Implementation
bool toBool() => validate().toLowerCase() == 'true';
Converts the string to a boolean value based on 'true' or 'false' string.
bool toBool() => validate().toLowerCase() == 'true';