TextStyleBuilder extension

A comprehensive text style extension for Flutter that provides a fluent interface for building and customizing text styles.

on

Properties

bold TextStyle

Available on num, provided by the TextStyleBuilder extension

Font weight modifiers
no setter
extraLight TextStyle

Available on num, provided by the TextStyleBuilder extension

no setter
extraWideSpacing TextStyle

Available on num, provided by the TextStyleBuilder extension

no setter
italic TextStyle

Available on num, provided by the TextStyleBuilder extension

Font style modifiers
no setter
light TextStyle

Available on num, provided by the TextStyleBuilder extension

no setter
lineThrough TextStyle

Available on num, provided by the TextStyleBuilder extension

no setter
looseHeight TextStyle

Available on num, provided by the TextStyleBuilder extension

no setter
medium TextStyle

Available on num, provided by the TextStyleBuilder extension

no setter
normalHeight TextStyle

Available on num, provided by the TextStyleBuilder extension

no setter
normalSpacing TextStyle

Available on num, provided by the TextStyleBuilder extension

no setter
overline TextStyle

Available on num, provided by the TextStyleBuilder extension

no setter
regular TextStyle

Available on num, provided by the TextStyleBuilder extension

no setter
relaxedHeight TextStyle

Available on num, provided by the TextStyleBuilder extension

no setter
semiBold TextStyle

Available on num, provided by the TextStyleBuilder extension

no setter
text TextStyle

Available on num, provided by the TextStyleBuilder extension

Creates a base TextStyle with the specified font size.
no setter
tightHeight TextStyle

Available on num, provided by the TextStyleBuilder extension

Line height modifiers
no setter
tightSpacing TextStyle

Available on num, provided by the TextStyleBuilder extension

Letter spacing modifiers
no setter
underline TextStyle

Available on num, provided by the TextStyleBuilder extension

Text decoration modifiers
no setter
wideSpacing TextStyle

Available on num, provided by the TextStyleBuilder extension

no setter

Methods

fontFamily(String family) TextStyle

Available on num, provided by the TextStyleBuilder extension

Font family modifiers
withBackground(Color color) TextStyle

Available on num, provided by the TextStyleBuilder extension

Background color application
withColor(Color color) TextStyle

Available on num, provided by the TextStyleBuilder extension

Color application
withShadow({Color color = const Color(0x33000000), double blurRadius = 2.0, Offset offset = Offset.zero}) TextStyle

Available on num, provided by the TextStyleBuilder extension

Shadow application