Zero class

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

border → const Border
Zero Border for containers or boxes.
borderRadius → const BorderRadius
Zero BorderRadius.
box → const SizedBox
A zero-sized SizedBox.
decoration → const BoxDecoration
A transparent borderless BoxDecoration.
duration → const Duration
Zero duration.
horizontal → const EdgeInsets
Zero EdgeInsets for horizontal and vertical directions.
insets → const EdgeInsets
Zero EdgeInsets (padding or margin).
offset → const Offset
Zero Offset.
radius → const Radius
Zero Radius for ShapeBorder or Circular widgets.
size → const Size
Zero Size object.
vertical → const EdgeInsets