BrandDesignTokens class
Professional design tokens class
Constructors
- BrandDesignTokens(BuildContext context)
Properties
- bodyMedium → TextStyle
-
no setter
- brandPrimary → Color
-
no setter
- brandSecondary → Color
-
no setter
- context → BuildContext
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- headlineLarge → TextStyle
-
no setter
- labelLarge → TextStyle
-
no setter
- radiusMedium → BorderRadius
-
no setter
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
-
shadowMedium
→ List<
BoxShadow> -
no setter
- spacingLG → double
-
no setter
- spacingMD → double
-
no setter
- surface → Color
-
no setter
- textPrimary → Color
-
no setter
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited