BrandKolors class abstract
A minimal yet comprehensive 12-color system for easy branding Covers all essential needs for any app without complexity
Constructors
- BrandKolors()
-
const
Properties
- accent → Color
-
no setter
- background → Color
-
no setter
- border → Color
-
no setter
- brightness → Brightness
-
no setter
- colorScheme → ColorScheme
-
Common getter to get a
ColorSchemefrom any stateno setteroverride - error → Color
-
no setter
- hashCode → int
-
The hash code for this object.
no setterinherited
- onAccent → Color
-
no setter
- onBackground → Color
-
no setter
- onError → Color
-
no setter
- onPrimary → Color
-
no setter
- onSecondary → Color
-
no setter
- onSurface → Color
-
no setter
- primary → Color
-
no setter
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- secondary → Color
-
no setter
- shadow → Color
-
no setter
- success → Color
-
no setter
- surface → Color
-
no setter
- surfaceVariant → Color
-
no setter
- textPrimary → Color
-
no setter
- textSecondary → Color
-
no setter
- textTertiary → Color
-
no setter
- warning → Color
-
no setter
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited