BreakpointMapper enum
Enum that maps to the Breakpoints class for consistent screen sizing.
Values
- xs → const BreakpointMapper
-
const BreakpointMapper(Breakpoints.xs, 'xs') - sm → const BreakpointMapper
-
const BreakpointMapper(Breakpoints.sm, 'sm') - md → const BreakpointMapper
-
const BreakpointMapper(Breakpoints.md, 'md') - lg → const BreakpointMapper
-
const BreakpointMapper(Breakpoints.lg, 'lg') - xl → const BreakpointMapper
-
const BreakpointMapper(Breakpoints.xl, 'xl') - xxl → const BreakpointMapper
-
const BreakpointMapper(Breakpoints.xxl, 'xxl')
Properties
- className → String
-
Short class name (e.g., 'sm', 'md').
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- index → int
-
A numeric identifier for the enumerated value.
no setterinherited
- isDesktop → bool
-
no setter
- isLaptop → bool
-
no setter
- isMiniDesktop → bool
-
no setter
- isMobile → bool
-
Convenience checks.
no setter
- isTablet → bool
-
no setter
- name → String
-
Available on Enum, provided by the EnumName extension
The name of the enum value.no setter - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- width → double
-
Max width for this breakpoint.
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Properties
-
valuesList
→ List<
BreakpointMapper> -
Returns all breakpoints.
final
Constants
-
values
→ const List<
BreakpointMapper> - A constant List of the values in this enum, in order of their declaration.