h method
Calculates the dynamic height based on the provided value and the screen dimensions.
The height method calculates the dynamic height based on the provided value and the screen dimensions.
value: The value representing a percentage of the initial height value.- Returns: The calculated dynamic height value.
Implementation
double h(double value) {
return MediaQueryData.fromView(WidgetsBinding.instance.window).size.height *
((value * 100 / _height) / 100);
}