OrkittThemeFoundation class abstract
A helper class to manage component themes. The abstract foundation for all Orkitt themes.
Defines the contract for building consistent theme data across light, dark, and brand-specific variants.
Constructors
Properties
- colorScheme → ColorScheme
-
no setter
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- textTheme → TextTheme
-
no setter
- typography → BrandTypo
-
no setter
Methods
-
buildTheme(
) → ThemeData - Returns the composed Flutter ThemeData.
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited