Swatch class
Generate Color Schema Based of Material Swatch Color
Constructors
- Swatch({required MaterialColor swatchColor, Brightness brightness = Brightness.light})
Properties
- brightness → Brightness
-
final
- colorScheme → ColorScheme
-
Common getter to get a
ColorSchemefrom any stateno setteroverride - hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- swatchColor → MaterialColor
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited