UiTheme class
A unified registry of all available UI brand themes. Easily switch between different design systems and their light/dark variants.
Constructors
- UiTheme()
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
of(
String name, {bool dark = false}) → BrandKolors -
=== Dynamic getter ===
Returns the theme by name.
darkdetermines light/dark variant.
Constants
- apple → const IOSBrandLightColors
- appleDark → const IOSBrandDarkColors
- bootstrap → const BootstrapLightColors
- bootstrapDark → const BootstrapDarkColors
- material → const GoogleMaterialLightColors
- materialDark → const GoogleMaterialDarkColors
- neutral → const NeutralLightColors
- neutralDark → const NeutralDarkColors
- soul → const LightOrkittColors
- soulDark → const DarkOrkittColors
- tailwind → const TailwindLightColors
- tailwindDark → const TailwindDarkColors
- twitter → const TwitterLightColors
- twitterDark → const TwitterDarkColors