UnifiedMarginPadding extension
Provides convenient spacing extensions on num for unified margin, padding, and sized box creation using a fixed unit.
- on
Properties
- gap → SizedBox
-
Available on num, provided by the UnifiedMarginPadding extension
Gap space:g(width & height)no setter - gapX → SizedBox
-
Available on num, provided by the UnifiedMarginPadding extension
Horizontal space:widthgapno setter - gapY → SizedBox
-
Available on num, provided by the UnifiedMarginPadding extension
Vertical space:heightgapno setter - m → EdgeInsets
-
Available on num, provided by the UnifiedMarginPadding extension
All sides margin:mno setter - mb → EdgeInsets
-
Available on num, provided by the UnifiedMarginPadding extension
Margin bottom only:mbno setter - ml → EdgeInsets
-
Available on num, provided by the UnifiedMarginPadding extension
Margin left only:mlno setter - mr → EdgeInsets
-
Available on num, provided by the UnifiedMarginPadding extension
Margin right only:mrno setter - mt → EdgeInsets
-
Available on num, provided by the UnifiedMarginPadding extension
Margin top only:mtno setter - mx → EdgeInsets
-
Available on num, provided by the UnifiedMarginPadding extension
Margin horizontal (left & right):mxno setter - my → EdgeInsets
-
Available on num, provided by the UnifiedMarginPadding extension
Margin vertical (top & bottom):myno setter - p → EdgeInsets
-
Available on num, provided by the UnifiedMarginPadding extension
All sides padding:pno setter - pb → EdgeInsets
-
Available on num, provided by the UnifiedMarginPadding extension
Padding bottom only:pbno setter - pl → EdgeInsets
-
Available on num, provided by the UnifiedMarginPadding extension
Padding left only:plno setter - pr → EdgeInsets
-
Available on num, provided by the UnifiedMarginPadding extension
Padding right only:prno setter - pt → EdgeInsets
-
Available on num, provided by the UnifiedMarginPadding extension
Padding top only:ptno setter - px → EdgeInsets
-
Available on num, provided by the UnifiedMarginPadding extension
Padding horizontal (left & right):pxno setter - py → EdgeInsets
-
Available on num, provided by the UnifiedMarginPadding extension
Padding vertical (top & bottom):pyno setter - s → SizedBox
-
Available on num, provided by the UnifiedMarginPadding extension
Square space:s(width & height)no setter