LanguageUtils class
A high-level localization utility class
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
describe(
Locale locale) → String - Convert a locale to a friendly display text
-
getFormatted(
Locale locale) → String - Get formatted name with language code
-
getName(
Locale locale) → String - Get native name of the locale
-
isRTL(
Locale locale) → bool - Check if this locale is RTL
-
supportedLocales(
) → List< Locale> - List all supported languages