ThemeColorExtract extension
The engine adheres to Material Design Guidelines to ensure visual consistency and maintainable theme architecture.
- on
Static Methods
-
fromHex(
String hexString) → Color -
Available on Color, provided by the ThemeColorExtract extension
Converts theColorobject to a hexadecimal string representation. The output can be customized to include or exclude the leading '#' symbol and the alpha (transparency) value.