CustomInputTheme class
Theme configuration for CustomInput.
Constructors
- CustomInputTheme({TextStyle? style, TextStyle? placeholderStyle, Color? cursorColor, double? cursorWidth, double? cursorHeight, Radius? cursorRadius, bool? cursorOpacityAnimates, EdgeInsetsGeometry? padding, EdgeInsetsGeometry? inputPadding, AlignmentGeometry? alignment, AlignmentGeometry? placeholderAlignment, MainAxisAlignment? mainAxisAlignment, CrossAxisAlignment? crossAxisAlignment, double gap = 8.0, double verticalGap = 0.0, BoxConstraints? constraints, EdgeInsetsGeometry? scrollbarPadding, BoxDecoration? decoration, BoxDecoration? focusedDecoration, BoxDecoration? disabledDecoration})
-
Creates a CustomInputTheme.
const
Properties
- alignment → AlignmentGeometry?
-
Default alignment of the input text.
final
- constraints → BoxConstraints?
-
Default constraints.
final
- crossAxisAlignment → CrossAxisAlignment?
-
Default cross axis alignment for the input row.
final
- cursorColor → Color?
-
Default cursor color.
final
- cursorHeight → double?
-
Default cursor height.
final
- cursorOpacityAnimates → bool?
-
Default cursor opacity animation behavior.
final
- cursorRadius → Radius?
-
Default cursor radius.
final
- cursorWidth → double?
-
Default cursor width.
final
- decoration → BoxDecoration?
-
Default decoration.
final
- disabledDecoration → BoxDecoration?
-
Decoration when the input is disabled.
final
- focusedDecoration → BoxDecoration?
-
Decoration when the input is focused.
final
- gap → double
-
Default gap between widgets.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- inputPadding → EdgeInsetsGeometry?
-
Default padding around the editable text.
final
- mainAxisAlignment → MainAxisAlignment?
-
Default main axis alignment for the input row.
final
- padding → EdgeInsetsGeometry?
-
Default padding around the entire input.
final
- placeholderAlignment → AlignmentGeometry?
-
Default alignment of the placeholder.
final
- placeholderStyle → TextStyle?
-
Default placeholder text style.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- scrollbarPadding → EdgeInsetsGeometry?
-
Default scrollbar padding.
final
- style → TextStyle?
-
Default text style for the input.
final
- verticalGap → double
-
Default vertical gap between top/bottom widgets.
final
Methods
-
copyWith(
{TextStyle? style, TextStyle? placeholderStyle, Color? cursorColor, double? cursorWidth, double? cursorHeight, Radius? cursorRadius, bool? cursorOpacityAnimates, EdgeInsetsGeometry? padding, EdgeInsetsGeometry? inputPadding, AlignmentGeometry? alignment, AlignmentGeometry? placeholderAlignment, MainAxisAlignment? mainAxisAlignment, CrossAxisAlignment? crossAxisAlignment, double? gap, double? verticalGap, BoxConstraints? constraints, EdgeInsetsGeometry? scrollbarPadding, BoxDecoration? decoration, BoxDecoration? focusedDecoration, BoxDecoration? disabledDecoration}) → CustomInputTheme - Creates a copy of this theme with the given fields replaced.
-
merge(
CustomInputTheme? other) → CustomInputTheme - Merges this theme with another theme.
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited