OrkittCircularProgressIndicatorThemeData class
- Inheritance
-
- Object
- ThemeExtension<
OrkittCircularProgressIndicatorThemeData> - OrkittProgressIndicatorThemeData<
OrkittCircularProgressIndicatorThemeData> - OrkittCircularProgressIndicatorThemeData
Constructors
- OrkittCircularProgressIndicatorThemeData(Color? color, Color? trackColor, double? strokeWidth, double? trackStrokeWidth)
Properties
- color → Color?
-
finalinherited
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- strokeWidth → double?
-
finalinherited
- trackColor → Color?
-
finalinherited
- trackStrokeWidth → double?
-
finalinherited
- type → Object
-
The extension's type.
no setterinherited
Methods
-
copyWith(
{Color? color, Color? trackColor, double? strokeWidth, double? trackStrokeWidth}) → ThemeExtension< OrkittCircularProgressIndicatorThemeData> -
Creates a copy of this theme extension with the given fields
replaced by the non-null parameter values.
override
-
lerp(
covariant ThemeExtension< OrkittCircularProgressIndicatorThemeData> ? other, double t) → ThemeExtension<OrkittCircularProgressIndicatorThemeData> -
Linearly interpolate with another ThemeExtension object.
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited