UiShapes class
Constructors
- UiShapes()
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
beveledRect(
{double radius = 8}) → BeveledRectangleBorder - Beveled rectangle with customizable radius.
-
circle(
) → CircleBorder - Circular shape (perfect circle).
-
outlineInputBorder(
{double radius = 8, Color borderColor = Colors.grey, double borderWidth = 1}) → OutlineInputBorder - Rounded rectangle border for input fields or containers.
-
roundedRect(
{double radius = 12}) → RoundedRectangleBorder - Rounded rectangle with customizable corner radius.
-
stadium(
) → StadiumBorder - Stadium shape (pill-shaped, fully rounded on short sides).
-
underlineInputBorder(
{Color borderColor = Colors.grey, double borderWidth = 1}) → UnderlineInputBorder - Underline border for input fields.