PriorityQueue<T> class
A generic priority queue implementation.
Constructors
- PriorityQueue(int comparator(T, T))
Properties
- comparator → int Function(T, T)
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- length → int
-
no setter
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
pop(
) → T -
push(
T element) → void -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited