SystemUI class
System UI Utilities
Constructors
- SystemUI()
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
enterFullScreen(
) → void - Enter full-screen mode.
-
exitFullScreen(
) → void - Exit full-screen mode.
-
hideStatusBar(
) → Future< void> - Hide the system status bar.
-
setDarkStatusBar(
) → void - Set dark status bar mode.
-
setLightStatusBar(
) → void - Set light status bar mode.
-
setOrientationLandscape(
) → void - Set device orientation to landscape mode.
-
setOrientationPortrait(
) → void - Set device orientation to portrait mode.
-
setStatusBarColor(
Color statusBarColor, {Brightness? statusBarBrightness, Brightness? statusBarIconBrightness, int delayInMilliSeconds = 200}) → Future< void> - Set status bar color and brightness.
-
showStatusBar(
) → Future< void> - Show the system status bar.